@@ -10,19 +10,19 @@ import ast
 import time
 import grpc
 import common_pb2_grpc
-import common_pb2 
+import common_pb2
 import re
 import numpy as np
 
 class JyInterface(object):
     period = '10s'
     def __init__(self, **kwargs):
-        """define parameters"""
+        """定义参数"""
         for k, v in kwargs.items():
-            setattr(self, k, v) 
+            setattr(self, k, v)
         self.grpcConfig(self.grpcAddress)
-
-    def grpcConfig(self, grpcAddress:str="52.221.223.196:9309"):
+        
+    def grpcConfig(self, grpcAddress:str="18.136.163.117:9309"):
         self.channel = grpc.insecure_channel(grpcAddress)
         self.stub = common_pb2_grpc.CommonServiceStub(self.channel)
     
@@ -51,7 +51,7 @@ class JyInterface(object):
         response = self.stub.getDepth(common_pb2.DepthRequest(type=self.type_,
                                                               symbols=symbol,
                                                               futureOrSpot=self.futureOrSpot))
-        return ast.literal_eval(response.message)
+        return ast.literal_eval(response.message.replace('null','"null"'))
 
     def getJumpPrice(self, symbol):
         response = self.stub.getJumpPrice(common_pb2.JumpPriceRequest(type=self.type_,
@@ -90,6 +90,7 @@ class JyInterface(object):
                                                                    amount=str(amount),
                                                                    appKey=self.appKey,
                                                                    secret=self.secret,
+                                                                   passphrase=self.passphrase,
                                                                    transferId=self.transferId))
         return response.message
     
@@ -98,7 +99,7 @@ class JyInterface(object):
                                                                        symbols=symbol,
                                                                        price=str(price),
                                                                        amount=str(amount),
-                                                                       appKey=self.appkey,
+                                                                       appKey=self.appKey,
                                                                        secret=self.secret,
                                                                        passphrase=self.passphrase,
                                                                        directOffset=directOffset,
@@ -117,14 +118,14 @@ class JyInterface(object):
         return response.message
     
     def getOrderInfoState(self, symbol, orderId):
-        response = self.stub.getOrderInfoState(common_pb2.getOrderInfoState(type=self.type_,
+        response = self.stub.getOrderInfoState(common_pb2.OrderInfoStateRequest (type=self.type_,
                                                                             symbols=symbol,
                                                                             orderId=str(orderId),
                                                                             appKey=self.appKey,
                                                                             secret=self.secret,
                                                                             passphrase=self.passphrase,
                                                                             futureOrSpot=self.futureOrSpot))
-        return response.message
+        return int(response.message)
     
     def getPosition(self, symbol):
         response = self.stub.getPosition(common_pb2.BalanceRequest(type=self.type_,
@@ -137,12 +138,12 @@ class JyInterface(object):
     
     def getUsdt(self):
         response = self.stub.getPosition(common_pb2.BalanceRequest(type=self.type_,
-                                                               appKey=self.appKey,
-                                                             secret=self.secret,
-                                                             passphrase=self.passphrase,
-                                                             futureOrSpot=self.futureOrSpot,
-                                                             mark="USDT")) 
-        return float(response.message[1:-1])       
+                                                                 appKey=self.appKey,
+                                                                 secret=self.secret,
+                                                                 passphrase=self.passphrase,
+                                                                 futureOrSpot=self.futureOrSpot,
+                                                                 mark="USDT")) 
+        return float(response.message[1:-1])     
     
     def getLastPrice(self, symbol):
         response = self.stub.getLastPrice(common_pb2.LastPriceRequest(type=self.type_, 
@@ -177,7 +178,7 @@ class JyInterface(object):
     
     def run(self, func):
         while True:
-            time.sleep(0.9)
+            time.sleep(1)
             try:
                 tmnum = int(re.sub("\D", "", self.period))   
                 tmstr = re.sub("[0-9]", "", self.period)
@@ -193,4 +194,3 @@ class JyInterface(object):
                 func()
             except:
                 pass
- 
\ No newline at end of file
